==> wordpress-2.0.2-da_DK.tar.gz: wordpress/wp-content/themes/default/attachment.php <==
<?php get_header(); ?>

	<div id="content" class="widecolumn">
				
  <?php if (have_posts()) : while (have_posts()) : the_post(); ?>
	
		<div class="navigation">
			<div class="alignleft">&nbsp;</div>
			<div class="alignright">&nbsp;</div>
		</div>
<?php $attachment_link = get_the_attachment_link($post->ID, true, array(450, 800)); // This also populates the iconsize for the next line ?>
<?php $_post = &get_post($post->ID); $classname = ($_post->iconsize[0] <= 128 ? 'small' : '') . 'attachment'; // This lets us style narrow icons specially ?>
		<div class="post" id="post-<?php the_ID(); ?>">
			<h2><a href="<?php echo get_permalink($post->post_parent); ?>" rev="attachment"><?php echo get_the_title($post->post_parent); ?></a> &raquo; <a href="<?php echo get_permalink() ?>" rel="bookmark" title="Permanent Link: <?php the_title(); ?>"><?php the_title(); ?></a></h2>
			<div class="entrytext">
				<p class="<?php echo $classname; ?>"><?php echo $attachment_link; ?><br /><?php echo basename($post->guid); ?></p>

				<?php the_content('<p class="serif">L&aelig;s resten af indl&aelig;gget &raquo;</p>'); ?>
	
				<?php link_pages('<p><strong>Sider:</strong> ', '</p>', 'number'); ?>
	
				<p class="postmetadata alt">
					<small>
						Dette indl&aelig;g blev skrevet
						<?php /* This is commented, because it requires a little adjusting sometimes.
							You'll need to download this plugin, and follow the instructions:
							http://binarybonsai.com/archives/2004/08/17/time-since-plugin/ */
							/* for $entry_datetime = abs(strtotime($post->post_date) - (60*120)); echo time_since($entry_datetime); echo ' siden'; */ ?> 
						den <?php the_time('l, j. F Y') ?> kl. <?php the_time('H:i') ?>
						og er gemt i <?php the_category(', ') ?>.
						Du kan f&oslash;lge kommentarer til indl&aelig;gget via vores <?php comments_rss_link('RSS 2.0'); ?>-feed. 
						
						<?php if (('open' == $post-> comment_status) && ('open' == $post->ping_status)) {
							// Both Comments and Pings are open ?>
							Du kan efterlade <a href="#respond">en kommentar</a> eller et <a href="<?php trackback_url(true); ?>" rel="trackback">trackback</a> fra din egen side.
						
						<?php } elseif (!('open' == $post-> comment_status) && ('open' == $post->ping_status)) {
							// Only Pings are Open ?>
							Der er i &oslash;jeblikket lukket for kommentarer, men du kan sende et <a href="<?php trackback_url(true); ?> " rel="trackback">trackback</a> fra din egen side.
						
						<?php } elseif (('open' == $post-> comment_status) && !('open' == $post->ping_status)) {
							// Comments are open, Pings are not ?>
							Du kan g&aring; til slutningen og efterlade en kommentar. Der er i &oslash;jeblikket lukket for pings.
			
						<?php } elseif (!('open' == $post-> comment_status) && !('open' == $post->ping_status)) {
							// Neither Comments, nor Pings are open ?>
							Der er lukket for b&aring;de kommentarer og pings i &oslash;jeblikket.			
						
						<?php } edit_post_link('Rediger dette indl&aelig;g.','',''); ?>
						
					</small>
				</p>
	
			</div>
		</div>
		
	<?php comments_template(); ?>
	
	<?php endwhile; else: ?>
	
		<p>Der var desv&aelig;rre ingen vedh&aelig;ftede filer, der matchede dine s&oslash;gekriterier.</p>
	
<?php endif; ?>
	
	</div>

<?php get_footer(); ?>

==> wordpress-2.0.11-da_DK.tar.gz: wordpress/wp-content/themes/default/attachment.php <==
<?php get_header(); ?>

	<div id="content" class="widecolumn">

  <?php if (have_posts()) : while (have_posts()) : the_post(); ?>

		<div class="navigation">
			<div class="alignleft">&nbsp;</div>
			<div class="alignright">&nbsp;</div>
		</div>
<?php $attachment_link = get_the_attachment_link($post->ID, true, array(450, 800)); // This also populates the iconsize for the next line ?>
<?php $_post = &get_post($post->ID); $classname = ($_post->iconsize[0] <= 128 ? 'small' : '') . 'attachment'; // This lets us style narrow icons specially ?>
		<div class="post" id="post-<?php the_ID(); ?>">
			<h2><a href="<?php echo get_permalink($post->post_parent); ?>" rev="attachment"><?php echo get_the_title($post->post_parent); ?></a> &raquo; <a href="<?php echo get_permalink() ?>" rel="bookmark" title="Permanent Link: <?php the_title(); ?>"><?php the_title(); ?></a></h2>
			<div class="entry">
				<p class="<?php echo $classname; ?>"><?php echo $attachment_link; ?><br /><?php echo basename($post->guid); ?></p>

				<?php the_content('<p class="serif">L&aelig;s resten af indl&aelig;gget &raquo;</p>'); ?>
	
				<?php link_pages('<p><strong>Sider:</strong> ', '</p>', 'number'); ?>
	
				<p class="postmetadata alt">
					<small>
						Dette indl&aelig;g blev skrevet
						<?php /* This is commented, because it requires a little adjusting sometimes.
							You'll need to download this plugin, and follow the instructions:
							http://binarybonsai.com/archives/2004/08/17/time-since-plugin/ */
							/* for $entry_datetime = abs(strtotime($post->post_date) - (60*120)); echo time_since($entry_datetime); echo ' siden'; */ ?> 
						den <?php the_time('l, j. F Y') ?> kl. <?php the_time('H:i') ?>
						og er gemt i <?php the_category(', ') ?>.
						Du kan f&oslash;lge kommentarer til indl&aelig;gget via vores <?php comments_rss_link('RSS 2.0'); ?>-feed. 
						
						<?php if (('open' == $post-> comment_status) && ('open' == $post->ping_status)) {
							// Both Comments and Pings are open ?>
							Du kan efterlade <a href="#respond">en kommentar</a> eller et <a href="<?php trackback_url(true); ?>" rel="trackback">trackback</a> fra din egen side.
						
						<?php } elseif (!('open' == $post-> comment_status) && ('open' == $post->ping_status)) {
							// Only Pings are Open ?>
							Der er i &oslash;jeblikket lukket for kommentarer, men du kan sende et <a href="<?php trackback_url(true); ?> " rel="trackback">trackback</a> fra din egen side.
						
						<?php } elseif (('open' == $post-> comment_status) && !('open' == $post->ping_status)) {
							// Comments are open, Pings are not ?>
							Du kan g&aring; til slutningen og efterlade en kommentar. Der er i &oslash;jeblikket lukket for pings.
			
						<?php } elseif (!('open' == $post-> comment_status) && !('open' == $post->ping_status)) {
							// Neither Comments, nor Pings are open ?>
							Der er lukket for b&aring;de kommentarer og pings i &oslash;jeblikket.			
						
						<?php } edit_post_link('Rediger dette indl&aelig;g.','',''); ?>
						
					</small>
				</p>

			</div>
		</div>

	<?php comments_template(); ?>

	<?php endwhile; else: ?>
	
		<p>Der var desv&aelig;rre ingen vedh&aelig;ftninger, der matchede dine s&oslash;gekriterier.</p>
	
<?php endif; ?>

	</div>

<?php get_footer(); ?>
